@@ -1,4 +1,4 @@
-/* $Id: generate_defs_libgnomeui.cc,v 1.4 2003/11/04 18:28:20 murrayc Exp $ */
+/* $Id: generate_defs_libgnomeui.cc,v 1.5 2004/04/06 21:16:41 mxpxpod Exp $ */
 
 /* generate_defs_libgnomeui.h
  *
@@ -34,7 +34,6 @@ int main (int argc, char *argv[])
             << get_defs( GNOME_TYPE_CLIENT )
             << get_defs( GNOME_TYPE_COLOR_PICKER )
             << get_defs( GNOME_TYPE_DATE_EDIT )
-            << get_defs( GNOME_TYPE_DIALOG )
             << get_defs( GNOME_TYPE_DRUID_PAGE_EDGE )
             << get_defs( GNOME_TYPE_DRUID_PAGE_STANDARD )
             << get_defs( GNOME_TYPE_DRUID_PAGE )
@@ -47,14 +46,11 @@ int main (int argc, char *argv[])
             << get_defs( GNOME_TYPE_ICON_LIST )
             << get_defs( GNOME_TYPE_ICON_SELECTION )
             << get_defs( GNOME_TYPE_ICON_TEXT_ITEM )
-            << get_defs( GNOME_TYPE_MDI_CHILD )
-            << get_defs( GNOME_TYPE_MDI_GENERIC_CHILD )
-            << get_defs( GNOME_TYPE_MDI )
-            << get_defs( GNOME_TYPE_MESSAGE_BOX )
+            << get_defs( GNOME_TYPE_PASSWORD_DIALOG )
             << get_defs( GNOME_TYPE_PIXMAP_ENTRY )
             << get_defs( GNOME_TYPE_PIXMAP )
-            << get_defs( GNOME_TYPE_PROPERTY_BOX )
-            << get_defs( GNOME_TYPE_SCORES );
+            << get_defs( GNOME_TYPE_SCORES )
+            << get_defs( GNOME_TYPE_THUMBNAIL_FACTORY );
 //            << get_defs( GNOME_TYPE_UI_INFO_TYPE )
 //            << get_defs( GNOME_TYPE_UI_INFO_CONFIGURABLE_TYPES )
 //            << get_defs( GNOME_TYPE_UI_PIXMAP_TYPE )
